"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_FrontDoor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRONT_DOOR_WEB_APPLICATION_FIREWALL_POLICIES_FIELD_NUMBER: builtins.int
    FRONT_DOORS_FIELD_NUMBER: builtins.int
    FRONT_DOORS_RULES_ENGINES_FIELD_NUMBER: builtins.int
    @property
    def front_door_web_application_firewall_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrontDoorWebApplicationFirewallPolicies]: ...
    @property
    def front_doors(self) -> global___FrontDoors: ...
    @property
    def front_doors_rules_engines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrontDoorsRulesEngines]: ...
    def __init__(
        self,
        *,
        front_door_web_application_firewall_policies: collections.abc.Iterable[global___FrontDoorWebApplicationFirewallPolicies] | None = ...,
        front_doors: global___FrontDoors | None = ...,
        front_doors_rules_engines: collections.abc.Iterable[global___FrontDoorsRulesEngines] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["front_doors", b"front_doors"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["front_door_web_application_firewall_policies", b"front_door_web_application_firewall_policies", "front_doors", b"front_doors", "front_doors_rules_engines", b"front_doors_rules_engines"]) -> None: ...

global___Microsoft_Network_FrontDoor = Microsoft_Network_FrontDoor

@typing_extensions.final
class LoadBalancingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    ADDITIONAL_LATENCY_MILLISECONDS_FIELD_NUMBER: builtins.int
    SAMPLE_SIZE_FIELD_NUMBER: builtins.int
    SUCCESSFUL_SAMPLES_REQUIRED_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    resource_state: builtins.str
    additional_latency_milliseconds: builtins.int
    sample_size: builtins.int
    successful_samples_required: builtins.int
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        resource_state: builtins.str = ...,
        additional_latency_milliseconds: builtins.int = ...,
        sample_size: builtins.int = ...,
        successful_samples_required: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_latency_milliseconds", b"additional_latency_milliseconds", "id", b"id", "name", b"name", "resource_state", b"resource_state", "sample_size", b"sample_size", "successful_samples_required", b"successful_samples_required"]) -> None: ...

global___LoadBalancingSettings = LoadBalancingSettings

@typing_extensions.final
class HealthProbeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_METHOD_FIELD_NUMBER: builtins.int
    INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    enabled_state: builtins.str
    health_probe_method: builtins.str
    interval_in_seconds: builtins.int
    path: builtins.str
    protocol: builtins.str
    resource_state: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        enabled_state: builtins.str = ...,
        health_probe_method: builtins.str = ...,
        interval_in_seconds: builtins.int = ...,
        path: builtins.str = ...,
        protocol: builtins.str = ...,
        resource_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_state", b"enabled_state", "health_probe_method", b"health_probe_method", "id", b"id", "interval_in_seconds", b"interval_in_seconds", "name", b"name", "path", b"path", "protocol", b"protocol", "resource_state", b"resource_state"]) -> None: ...

global___HealthProbeSettings = HealthProbeSettings

@typing_extensions.final
class FrontDoorWebApplicationFirewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_RULES_FIELD_NUMBER: builtins.int
    MANAGED_RULES_FIELD_NUMBER: builtins.int
    POLICY_SETTINGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def custom_rules(self) -> global___CustomRuleList: ...
    @property
    def managed_rules(self) -> global___ManagedRuleSetList: ...
    @property
    def policy_settings(self) -> global___PolicySettings: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sku(self) -> global___Sku: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        custom_rules: global___CustomRuleList | None = ...,
        managed_rules: global___ManagedRuleSetList | None = ...,
        policy_settings: global___PolicySettings | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sku: global___Sku | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "managed_rules", b"managed_rules", "policy_settings", b"policy_settings", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "etag", b"etag", "location", b"location", "managed_rules", b"managed_rules", "name", b"name", "policy_settings", b"policy_settings", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___FrontDoorWebApplicationFirewallPolicies = FrontDoorWebApplicationFirewallPolicies

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class PolicySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_BLOCK_RESPONSE_BODY_FIELD_NUMBER: builtins.int
    CUSTOM_BLOCK_RESPONSE_STATUS_CODE_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    custom_block_response_body: builtins.str
    custom_block_response_status_code: builtins.int
    enabled_state: builtins.str
    mode: builtins.str
    redirect_url: builtins.str
    def __init__(
        self,
        *,
        custom_block_response_body: builtins.str = ...,
        custom_block_response_status_code: builtins.int = ...,
        enabled_state: builtins.str = ...,
        mode: builtins.str = ...,
        redirect_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_block_response_body", b"custom_block_response_body", "custom_block_response_status_code", b"custom_block_response_status_code", "enabled_state", b"enabled_state", "mode", b"mode", "redirect_url", b"redirect_url"]) -> None: ...

global___PolicySettings = PolicySettings

@typing_extensions.final
class ManagedRuleSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RULE_SETS_FIELD_NUMBER: builtins.int
    @property
    def managed_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleSet]: ...
    def __init__(
        self,
        *,
        managed_rule_sets: collections.abc.Iterable[global___ManagedRuleSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_rule_sets", b"managed_rule_sets"]) -> None: ...

global___ManagedRuleSetList = ManagedRuleSetList

@typing_extensions.final
class ManagedRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RULE_GROUP_OVERRIDES_FIELD_NUMBER: builtins.int
    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    RULE_SET_ACTION_FIELD_NUMBER: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleExclusion]: ...
    @property
    def rule_group_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleGroupOverride]: ...
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    rule_set_action: builtins.str
    def __init__(
        self,
        *,
        exclusions: collections.abc.Iterable[global___ManagedRuleExclusion] | None = ...,
        rule_group_overrides: collections.abc.Iterable[global___ManagedRuleGroupOverride] | None = ...,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
        rule_set_action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusions", b"exclusions", "rule_group_overrides", b"rule_group_overrides", "rule_set_action", b"rule_set_action", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ManagedRuleSet = ManagedRuleSet

@typing_extensions.final
class ManagedRuleGroupOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleExclusion]: ...
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleOverride]: ...
    def __init__(
        self,
        *,
        exclusions: collections.abc.Iterable[global___ManagedRuleExclusion] | None = ...,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[global___ManagedRuleOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusions", b"exclusions", "rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ManagedRuleGroupOverride = ManagedRuleGroupOverride

@typing_extensions.final
class ManagedRuleOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    EXCLUSIONS_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    action: builtins.str
    enabled_state: builtins.str
    @property
    def exclusions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleExclusion]: ...
    rule_id: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        enabled_state: builtins.str = ...,
        exclusions: collections.abc.Iterable[global___ManagedRuleExclusion] | None = ...,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "enabled_state", b"enabled_state", "exclusions", b"exclusions", "rule_id", b"rule_id"]) -> None: ...

global___ManagedRuleOverride = ManagedRuleOverride

@typing_extensions.final
class ManagedRuleExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SELECTOR_MATCH_OPERATOR_FIELD_NUMBER: builtins.int
    match_variable: builtins.str
    selector: builtins.str
    selector_match_operator: builtins.str
    def __init__(
        self,
        *,
        match_variable: builtins.str = ...,
        selector: builtins.str = ...,
        selector_match_operator: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_variable", b"match_variable", "selector", b"selector", "selector_match_operator", b"selector_match_operator"]) -> None: ...

global___ManagedRuleExclusion = ManagedRuleExclusion

@typing_extensions.final
class CustomRuleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomRule]: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___CustomRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rules", b"rules"]) -> None: ...

global___CustomRuleList = CustomRuleList

@typing_extensions.final
class CustomRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RATE_LIMIT_DURATION_IN_MINUTES_FIELD_NUMBER: builtins.int
    RATE_LIMIT_THRESHOLD_FIELD_NUMBER: builtins.int
    RULE_TYPE_FIELD_NUMBER: builtins.int
    action: builtins.str
    enabled_state: builtins.str
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchCondition]: ...
    name: builtins.str
    priority: builtins.int
    rate_limit_duration_in_minutes: builtins.int
    rate_limit_threshold: builtins.int
    rule_type: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        enabled_state: builtins.str = ...,
        match_conditions: collections.abc.Iterable[global___MatchCondition] | None = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rate_limit_duration_in_minutes: builtins.int = ...,
        rate_limit_threshold: builtins.int = ...,
        rule_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "enabled_state", b"enabled_state", "match_conditions", b"match_conditions", "name", b"name", "priority", b"priority", "rate_limit_duration_in_minutes", b"rate_limit_duration_in_minutes", "rate_limit_threshold", b"rate_limit_threshold", "rule_type", b"rule_type"]) -> None: ...

global___CustomRule = CustomRule

@typing_extensions.final
class MatchCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VALUE_FIELD_NUMBER: builtins.int
    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    NEGATE_CONDITION_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def match_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    match_variable: builtins.str
    negate_condition: builtins.bool
    operator: builtins.str
    selector: builtins.str
    @property
    def transforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        match_value: collections.abc.Iterable[builtins.str] | None = ...,
        match_variable: builtins.str = ...,
        negate_condition: builtins.bool = ...,
        operator: builtins.str = ...,
        selector: builtins.str = ...,
        transforms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_value", b"match_value", "match_variable", b"match_variable", "negate_condition", b"negate_condition", "operator", b"operator", "selector", b"selector", "transforms", b"transforms"]) -> None: ...

global___MatchCondition = MatchCondition

@typing_extensions.final
class FrontDoorsRulesEngines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    resource_state: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RulesEngineRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        resource_state: builtins.str = ...,
        rules: collections.abc.Iterable[global___RulesEngineRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "resource_state", b"resource_state", "rules", b"rules"]) -> None: ...

global___FrontDoorsRulesEngines = FrontDoorsRulesEngines

@typing_extensions.final
class RulesEngineRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    MATCH_PROCESSING_BEHAVIOR_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    @property
    def action(self) -> global___RulesEngineAction: ...
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RulesEngineMatchCondition]: ...
    match_processing_behavior: builtins.str
    name: builtins.str
    priority: builtins.int
    def __init__(
        self,
        *,
        action: global___RulesEngineAction | None = ...,
        match_conditions: collections.abc.Iterable[global___RulesEngineMatchCondition] | None = ...,
        match_processing_behavior: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "match_conditions", b"match_conditions", "match_processing_behavior", b"match_processing_behavior", "name", b"name", "priority", b"priority"]) -> None: ...

global___RulesEngineRule = RulesEngineRule

@typing_extensions.final
class RulesEngineMatchCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEGATE_CONDITION_FIELD_NUMBER: builtins.int
    RULES_ENGINE_MATCH_VALUE_FIELD_NUMBER: builtins.int
    RULES_ENGINE_MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    RULES_ENGINE_OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TRANSFORMS_FIELD_NUMBER: builtins.int
    negate_condition: builtins.bool
    @property
    def rules_engine_match_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    rules_engine_match_variable: builtins.str
    rules_engine_operator: builtins.str
    selector: builtins.str
    @property
    def transforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        negate_condition: builtins.bool = ...,
        rules_engine_match_value: collections.abc.Iterable[builtins.str] | None = ...,
        rules_engine_match_variable: builtins.str = ...,
        rules_engine_operator: builtins.str = ...,
        selector: builtins.str = ...,
        transforms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["negate_condition", b"negate_condition", "rules_engine_match_value", b"rules_engine_match_value", "rules_engine_match_variable", b"rules_engine_match_variable", "rules_engine_operator", b"rules_engine_operator", "selector", b"selector", "transforms", b"transforms"]) -> None: ...

global___RulesEngineMatchCondition = RulesEngineMatchCondition

@typing_extensions.final
class RulesEngineAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADER_ACTIONS_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_ACTIONS_FIELD_NUMBER: builtins.int
    ROUTE_CONFIGURATION_OVERRIDE_FIELD_NUMBER: builtins.int
    @property
    def request_header_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderAction]: ...
    @property
    def response_header_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HeaderAction]: ...
    @property
    def route_configuration_override(self) -> global___RouteConfiguration: ...
    def __init__(
        self,
        *,
        request_header_actions: collections.abc.Iterable[global___HeaderAction] | None = ...,
        response_header_actions: collections.abc.Iterable[global___HeaderAction] | None = ...,
        route_configuration_override: global___RouteConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_configuration_override", b"route_configuration_override"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_header_actions", b"request_header_actions", "response_header_actions", b"response_header_actions", "route_configuration_override", b"route_configuration_override"]) -> None: ...

global___RulesEngineAction = RulesEngineAction

@typing_extensions.final
class HeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_ACTION_TYPE_FIELD_NUMBER: builtins.int
    HEADER_NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    header_action_type: builtins.str
    header_name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        header_action_type: builtins.str = ...,
        header_name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_action_type", b"header_action_type", "header_name", b"header_name", "value", b"value"]) -> None: ...

global___HeaderAction = HeaderAction

@typing_extensions.final
class FrontDoors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKEND_POOLS_FIELD_NUMBER: builtins.int
    BACKEND_POOLS_SETTINGS_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    FRONTEND_ENDPOINTS_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_SETTINGS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    ROUTING_RULES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def backend_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackendPool]: ...
    @property
    def backend_pools_settings(self) -> global___BackendPoolsSettings: ...
    enabled_state: builtins.str
    friendly_name: builtins.str
    @property
    def frontend_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrontendEndpoint]: ...
    @property
    def health_probe_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthProbeSettings]: ...
    @property
    def load_balancing_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LoadBalancingSettings]: ...
    resource_state: builtins.str
    @property
    def routing_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingRule]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backend_pools: collections.abc.Iterable[global___BackendPool] | None = ...,
        backend_pools_settings: global___BackendPoolsSettings | None = ...,
        enabled_state: builtins.str = ...,
        friendly_name: builtins.str = ...,
        frontend_endpoints: collections.abc.Iterable[global___FrontendEndpoint] | None = ...,
        health_probe_settings: collections.abc.Iterable[global___HealthProbeSettings] | None = ...,
        load_balancing_settings: collections.abc.Iterable[global___LoadBalancingSettings] | None = ...,
        resource_state: builtins.str = ...,
        routing_rules: collections.abc.Iterable[global___RoutingRule] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend_pools_settings", b"backend_pools_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_pools", b"backend_pools", "backend_pools_settings", b"backend_pools_settings", "enabled_state", b"enabled_state", "friendly_name", b"friendly_name", "frontend_endpoints", b"frontend_endpoints", "health_probe_settings", b"health_probe_settings", "load_balancing_settings", b"load_balancing_settings", "location", b"location", "name", b"name", "resource_info", b"resource_info", "resource_state", b"resource_state", "routing_rules", b"routing_rules", "tags", b"tags"]) -> None: ...

global___FrontDoors = FrontDoors

@typing_extensions.final
class RoutingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    PATTERNS_TO_MATCH_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    ROUTE_CONFIGURATION_FIELD_NUMBER: builtins.int
    RULES_ENGINE_FIELD_NUMBER: builtins.int
    WEB_APPLICATION_FIREWALL_POLICY_LINK_FIELD_NUMBER: builtins.int
    FRONTEND_ENDPOINTS_FIELD_NUMBER: builtins.int
    ACCEPTED_PROTOCOLS_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    enabled_state: builtins.str
    @property
    def patterns_to_match(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    resource_state: builtins.str
    @property
    def route_configuration(self) -> global___RouteConfiguration: ...
    rules_engine: builtins.str
    @property
    def web_application_firewall_policy_link(self) -> global___RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink: ...
    @property
    def frontend_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrontendEndpoint]: ...
    accepted_protocols: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        enabled_state: builtins.str = ...,
        patterns_to_match: collections.abc.Iterable[builtins.str] | None = ...,
        resource_state: builtins.str = ...,
        route_configuration: global___RouteConfiguration | None = ...,
        rules_engine: builtins.str = ...,
        web_application_firewall_policy_link: global___RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink | None = ...,
        frontend_endpoints: collections.abc.Iterable[global___FrontendEndpoint] | None = ...,
        accepted_protocols: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_configuration", b"route_configuration", "web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_protocols", b"accepted_protocols", "enabled_state", b"enabled_state", "frontend_endpoints", b"frontend_endpoints", "id", b"id", "name", b"name", "patterns_to_match", b"patterns_to_match", "resource_state", b"resource_state", "route_configuration", b"route_configuration", "rules_engine", b"rules_engine", "web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> None: ...

global___RoutingRule = RoutingRule

@typing_extensions.final
class RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink = RoutingRuleUpdateParametersWebApplicationFirewallPolicyLink

@typing_extensions.final
class RouteConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RouteConfiguration = RouteConfiguration

@typing_extensions.final
class FrontendEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_ENABLED_STATE_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_TTL_SECONDS_FIELD_NUMBER: builtins.int
    WEB_APPLICATION_FIREWALL_POLICY_LINK_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    host_name: builtins.str
    resource_state: builtins.str
    session_affinity_enabled_state: builtins.str
    session_affinity_ttl_seconds: builtins.int
    @property
    def web_application_firewall_policy_link(self) -> global___FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        host_name: builtins.str = ...,
        resource_state: builtins.str = ...,
        session_affinity_enabled_state: builtins.str = ...,
        session_affinity_ttl_seconds: builtins.int = ...,
        web_application_firewall_policy_link: global___FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_name", b"host_name", "id", b"id", "name", b"name", "resource_state", b"resource_state", "session_affinity_enabled_state", b"session_affinity_enabled_state", "session_affinity_ttl_seconds", b"session_affinity_ttl_seconds", "web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> None: ...

global___FrontendEndpoint = FrontendEndpoint

@typing_extensions.final
class FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink = FrontendEndpointUpdateParametersWebApplicationFirewallPolicyLink

@typing_extensions.final
class BackendPoolsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENFORCE_CERTIFICATE_NAME_CHECK_FIELD_NUMBER: builtins.int
    SEND_RECV_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    enforce_certificate_name_check: builtins.str
    send_recv_timeout_seconds: builtins.int
    def __init__(
        self,
        *,
        enforce_certificate_name_check: builtins.str = ...,
        send_recv_timeout_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enforce_certificate_name_check", b"enforce_certificate_name_check", "send_recv_timeout_seconds", b"send_recv_timeout_seconds"]) -> None: ...

global___BackendPoolsSettings = BackendPoolsSettings

@typing_extensions.final
class BackendPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKENDS_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_SETTINGS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_STATE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    @property
    def backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Backend]: ...
    @property
    def health_probe_settings(self) -> global___HealthProbeSettings: ...
    @property
    def load_balancing_settings(self) -> global___LoadBalancingSettings: ...
    resource_state: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        backends: collections.abc.Iterable[global___Backend] | None = ...,
        health_probe_settings: global___HealthProbeSettings | None = ...,
        load_balancing_settings: global___LoadBalancingSettings | None = ...,
        resource_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "load_balancing_settings", b"load_balancing_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backends", b"backends", "health_probe_settings", b"health_probe_settings", "id", b"id", "load_balancing_settings", b"load_balancing_settings", "name", b"name", "resource_state", b"resource_state"]) -> None: ...

global___BackendPool = BackendPool

@typing_extensions.final
class Backend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    BACKEND_HOST_HEADER_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    HTTP_PORT_FIELD_NUMBER: builtins.int
    HTTPS_PORT_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_ALIAS_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_APPROVAL_MESSAGE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    address: builtins.str
    backend_host_header: builtins.str
    enabled_state: builtins.str
    http_port: builtins.int
    https_port: builtins.int
    priority: builtins.int
    private_link_alias: builtins.str
    private_link_approval_message: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        backend_host_header: builtins.str = ...,
        enabled_state: builtins.str = ...,
        http_port: builtins.int = ...,
        https_port: builtins.int = ...,
        priority: builtins.int = ...,
        private_link_alias: builtins.str = ...,
        private_link_approval_message: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "backend_host_header", b"backend_host_header", "enabled_state", b"enabled_state", "http_port", b"http_port", "https_port", b"https_port", "priority", b"priority", "private_link_alias", b"private_link_alias", "private_link_approval_message", b"private_link_approval_message", "weight", b"weight"]) -> None: ...

global___Backend = Backend



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Kubernetes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTED_CLUSTERS_FIELD_NUMBER: builtins.int
    @property
    def connected_clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectedClusters]: ...
    def __init__(
        self,
        *,
        connected_clusters: collections.abc.Iterable[global___ConnectedClusters] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connected_clusters", b"connected_clusters"]) -> None: ...

global___Microsoft_Kubernetes = Microsoft_Kubernetes

@typing_extensions.final
class ConnectedClusters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AGENT_PUBLIC_KEY_CERTIFICATE_FIELD_NUMBER: builtins.int
    DISTRIBUTION_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ConnectedClusterIdentity: ...
    location: builtins.str
    name: builtins.str
    agent_public_key_certificate: builtins.str
    distribution: builtins.str
    infrastructure: builtins.str
    provisioning_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ConnectedClusterIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        agent_public_key_certificate: builtins.str = ...,
        distribution: builtins.str = ...,
        infrastructure: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_public_key_certificate", b"agent_public_key_certificate", "distribution", b"distribution", "identity", b"identity", "infrastructure", b"infrastructure", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ConnectedClusters = ConnectedClusters

@typing_extensions.final
class ConnectedClusterIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ConnectedClusterIdentity = ConnectedClusterIdentity



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GroupTagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___GroupTagFilter = GroupTagFilter

@typing_extensions.final
class GroupQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FILTERS_FIELD_NUMBER: builtins.int
    STACK_IDENTIFIER_FIELD_NUMBER: builtins.int
    TAG_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resource_type_filters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    stack_identifier: builtins.str
    @property
    def tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupTagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_type_filters: collections.abc.Iterable[builtins.str] | None = ...,
        stack_identifier: builtins.str = ...,
        tag_filters: collections.abc.Iterable[global___GroupTagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_type_filters", b"resource_type_filters", "stack_identifier", b"stack_identifier", "tag_filters", b"tag_filters"]) -> None: ...

global___GroupQuery = GroupQuery

@typing_extensions.final
class GroupResourceQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def query(self) -> global___GroupQuery: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        query: global___GroupQuery | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["query", b"query", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query", "resource_info", b"resource_info"]) -> None: ...

global___GroupResourceQuery = GroupResourceQuery

@typing_extensions.final
class Group(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_QUERY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def resource_query(self) -> global___GroupResourceQuery: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        resource_query: global___GroupResourceQuery | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_query", b"resource_query"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "resource_query", b"resource_query", "tags", b"tags"]) -> None: ...

global___Group = Group

@typing_extensions.final
class ResourceGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    @property
    def group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Group]: ...
    def __init__(
        self,
        *,
        group: collections.abc.Iterable[global___Group] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group"]) -> None: ...

global___ResourceGroups = ResourceGroups



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_virtualnetworks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3azure/azure_microsoft_network_virtualnetworks.proto\x12\x33oak9.tython.azure.microsoft_network_virtualnetworks\x1a\x13shared/shared.proto\"\x82\x03\n!Microsoft_Network_virtualNetworks\x12^\n\x10virtual_networks\x18\x01 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworks\x12m\n\x18virtual_networks_subnets\x18\x02 \x03(\x0b\x32K.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworksSubnets\x12\x8d\x01\n)virtual_networks_virtual_network_peerings\x18\x03 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworksVirtualNetworkPeerings\"\"\n\x14NetworkSecurityGroup\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\nRouteTable\x12\n\n\x02id\x18\x01 \x01(\t\"\x19\n\x0bNatGateways\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x44\x64osProtectionPlan\x12\n\n\x02id\x18\x01 \x01(\t\"\xfc\x03\n%VirtualNetworksVirtualNetworkPeerings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x1c\x61llow_virtual_network_access\x18\x03 \x01(\x08\x12\x1f\n\x17\x61llow_forwarded_traffic\x18\x04 \x01(\x08\x12\x1d\n\x15\x61llow_gateway_transit\x18\x05 \x01(\x08\x12\x1b\n\x13use_remote_gateways\x18\x06 \x01(\x08\x12\x1e\n\x16remote_virtual_network\x18\x07 \x01(\t\x12_\n\x14remote_address_space\x18\x08 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_virtualnetworks.AddressSpace\x12q\n\x16remote_bgp_communities\x18\t \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworkBgpCommunities\x12\x15\n\rpeering_state\x18\n \x01(\t\"\xc3\x05\n\x16VirtualNetworksSubnets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x03 \x01(\t\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x04 \x03(\t\x12i\n\x16network_security_group\x18\x05 \x01(\x0b\x32I.oak9.tython.azure.microsoft_network_virtualnetworks.NetworkSecurityGroup\x12T\n\x0broute_table\x18\x06 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_virtualnetworks.RouteTable\x12\x13\n\x0bnat_gateway\x18\x07 \x01(\t\x12o\n\x11service_endpoints\x18\x08 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_virtualnetworks.ServiceEndpointPropertiesFormat\x12!\n\x19service_endpoint_policies\x18\t \x03(\t\x12\x16\n\x0eip_allocations\x18\n \x03(\t\x12T\n\x0b\x64\x65legations\x18\x0b \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_virtualnetworks.Delegation\x12)\n!private_endpoint_network_policies\x18\x0c \x01(\t\x12-\n%private_link_service_network_policies\x18\r \x01(\t\"\xee\x07\n\x0fVirtualNetworks\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\\\n\x04tags\x18\x04 \x03(\x0b\x32N.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworks.TagsEntry\x12`\n\x11\x65xtended_location\x18\x05 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_network_virtualnetworks.ExtendedLocation\x12X\n\raddress_space\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_virtualnetworks.AddressSpace\x12V\n\x0c\x64hcp_options\x18\x07 \x01(\x0b\x32@.oak9.tython.azure.microsoft_network_virtualnetworks.DhcpOptions\x12L\n\x07subnets\x18\x08 \x03(\x0b\x32;.oak9.tython.azure.microsoft_network_virtualnetworks.Subnet\x12l\n\x18virtual_network_peerings\x18\t \x03(\x0b\x32J.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworkPeering\x12\x1e\n\x16\x65nable_ddos_protection\x18\n \x01(\x08\x12\x1c\n\x14\x65nable_vm_protection\x18\x0b \x01(\x08\x12\x65\n\x14\x64\x64os_protection_plan\x18\x0c \x01(\x0b\x32G.oak9.tython.azure.microsoft_network_virtualnetworks.DdosProtectionPlan\x12j\n\x0f\x62gp_communities\x18\r \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworkBgpCommunities\x12\x16\n\x0eip_allocations\x18\x0e \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x03\n\x15VirtualNetworkPeering\x12$\n\x1c\x61llow_virtual_network_access\x18\x01 \x01(\x08\x12\x1f\n\x17\x61llow_forwarded_traffic\x18\x02 \x01(\x08\x12\x1d\n\x15\x61llow_gateway_transit\x18\x03 \x01(\x08\x12\x1b\n\x13use_remote_gateways\x18\x04 \x01(\x08\x12\x1e\n\x16remote_virtual_network\x18\x05 \x01(\t\x12_\n\x14remote_address_space\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_network_virtualnetworks.AddressSpace\x12q\n\x16remote_bgp_communities\x18\x07 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_network_virtualnetworks.VirtualNetworkBgpCommunities\x12\x15\n\rpeering_state\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"A\n\x1cVirtualNetworkBgpCommunities\x12!\n\x19virtual_network_community\x18\x01 \x01(\t\"\xfa\x04\n\x06Subnet\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\t\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x02 \x03(\t\x12i\n\x16network_security_group\x18\x03 \x01(\x0b\x32I.oak9.tython.azure.microsoft_network_virtualnetworks.NetworkSecurityGroup\x12T\n\x0broute_table\x18\x04 \x01(\x0b\x32?.oak9.tython.azure.microsoft_network_virtualnetworks.RouteTable\x12\x13\n\x0bnat_gateway\x18\x05 \x01(\t\x12o\n\x11service_endpoints\x18\x06 \x03(\x0b\x32T.oak9.tython.azure.microsoft_network_virtualnetworks.ServiceEndpointPropertiesFormat\x12!\n\x19service_endpoint_policies\x18\x07 \x03(\t\x12\x16\n\x0eip_allocations\x18\x08 \x03(\t\x12T\n\x0b\x64\x65legations\x18\t \x03(\x0b\x32?.oak9.tython.azure.microsoft_network_virtualnetworks.Delegation\x12)\n!private_endpoint_network_policies\x18\n \x01(\t\x12-\n%private_link_service_network_policies\x18\x0b \x01(\t\x12\x0c\n\x04name\x18\x0c \x01(\t\"0\n\nDelegation\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x1fServiceEndpointPropertiesFormat\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tlocations\x18\x02 \x03(\t\"\"\n\x0b\x44hcpOptions\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\"(\n\x0c\x41\x64\x64ressSpace\x12\x18\n\x10\x61\x64\x64ress_prefixes\x18\x01 \x03(\t\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_virtualnetworks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VIRTUALNETWORKS_TAGSENTRY._options = None
  _VIRTUALNETWORKS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_VIRTUALNETWORKS._serialized_start=130
  _MICROSOFT_NETWORK_VIRTUALNETWORKS._serialized_end=516
  _NETWORKSECURITYGROUP._serialized_start=518
  _NETWORKSECURITYGROUP._serialized_end=552
  _ROUTETABLE._serialized_start=554
  _ROUTETABLE._serialized_end=578
  _NATGATEWAYS._serialized_start=580
  _NATGATEWAYS._serialized_end=605
  _DDOSPROTECTIONPLAN._serialized_start=607
  _DDOSPROTECTIONPLAN._serialized_end=639
  _VIRTUALNETWORKSVIRTUALNETWORKPEERINGS._serialized_start=642
  _VIRTUALNETWORKSVIRTUALNETWORKPEERINGS._serialized_end=1150
  _VIRTUALNETWORKSSUBNETS._serialized_start=1153
  _VIRTUALNETWORKSSUBNETS._serialized_end=1860
  _VIRTUALNETWORKS._serialized_start=1863
  _VIRTUALNETWORKS._serialized_end=2869
  _VIRTUALNETWORKS_TAGSENTRY._serialized_start=2826
  _VIRTUALNETWORKS_TAGSENTRY._serialized_end=2869
  _VIRTUALNETWORKPEERING._serialized_start=2872
  _VIRTUALNETWORKPEERING._serialized_end=3307
  _VIRTUALNETWORKBGPCOMMUNITIES._serialized_start=3309
  _VIRTUALNETWORKBGPCOMMUNITIES._serialized_end=3374
  _SUBNET._serialized_start=3377
  _SUBNET._serialized_end=4011
  _DELEGATION._serialized_start=4013
  _DELEGATION._serialized_end=4061
  _SERVICEENDPOINTPROPERTIESFORMAT._serialized_start=4063
  _SERVICEENDPOINTPROPERTIESFORMAT._serialized_end=4132
  _DHCPOPTIONS._serialized_start=4134
  _DHCPOPTIONS._serialized_end=4168
  _ADDRESSSPACE._serialized_start=4170
  _ADDRESSSPACE._serialized_end=4210
  _EXTENDEDLOCATION._serialized_start=4212
  _EXTENDEDLOCATION._serialized_end=4258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_kms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_kms.proto\x12\x13oak9.tython.gcp.kms\x1a\x13shared/shared.proto\"G\n\x15KmsCryptoKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"K\n\x1cKmsCryptoKeyXVersionTemplate\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x18\n\x10protection_level\x18\x02 \x01(\t\"\xf6\x03\n\x0cKmsCryptoKey\x12\"\n\x1a\x64\x65stroy_scheduled_duration\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bimport_only\x18\x03 \x01(\x08\x12\x10\n\x08key_ring\x18\x04 \x01(\t\x12=\n\x06labels\x18\x05 \x03(\x0b\x32-.oak9.tython.gcp.kms.KmsCryptoKey.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07purpose\x18\x07 \x01(\t\x12\x17\n\x0frotation_period\x18\x08 \x01(\t\x12%\n\x1dskip_initial_version_creation\x18\t \x01(\x08\x12<\n\x08timeouts\x18\n \x01(\x0b\x32*.oak9.tython.gcp.kms.KmsCryptoKeyXTimeouts\x12K\n\x10version_template\x18\x0b \x01(\x0b\x32\x31.oak9.tython.gcp.kms.KmsCryptoKeyXVersionTemplate\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Z\n KmsCryptoKeyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xeb\x01\n\x16KmsCryptoKeyIamBinding\x12\x15\n\rcrypto_key_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12H\n\tcondition\x18\x06 \x01(\x0b\x32\x35.oak9.tython.gcp.kms.KmsCryptoKeyIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\x1fKmsCryptoKeyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe8\x01\n\x15KmsCryptoKeyIamMember\x12\x15\n\rcrypto_key_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12G\n\tcondition\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.kms.KmsCryptoKeyIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x96\x01\n\x15KmsCryptoKeyIamPolicy\x12\x15\n\rcrypto_key_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"5\n\x13KmsKeyRingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xbe\x01\n\nKmsKeyRing\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12:\n\x08timeouts\x18\x05 \x01(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1eKmsKeyRingIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe5\x01\n\x14KmsKeyRingIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bkey_ring_id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x46\n\tcondition\x18\x06 \x01(\x0b\x32\x33.oak9.tython.gcp.kms.KmsKeyRingIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x1dKmsKeyRingIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xe2\x01\n\x13KmsKeyRingIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bkey_ring_id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x45\n\tcondition\x18\x06 \x01(\x0b\x32\x32.oak9.tython.gcp.kms.KmsKeyRingIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x13KmsKeyRingIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bkey_ring_id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\">\n\x1cKmsKeyRingImportJobXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xae\x04\n\x13KmsKeyRingImportJob\x12N\n\x0b\x61ttestation\x18\x01 \x03(\x0b\x32\x39.oak9.tython.gcp.kms.KmsKeyRingImportJob.AttestationEntry\x12\x13\n\x0b\x65xpire_time\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x15\n\rimport_job_id\x18\x04 \x01(\t\x12\x15\n\rimport_method\x18\x05 \x01(\t\x12\x10\n\x08key_ring\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x18\n\x10protection_level\x18\x08 \x01(\t\x12K\n\npublic_key\x18\t \x03(\x0b\x32\x37.oak9.tython.gcp.kms.KmsKeyRingImportJob.PublicKeyEntry\x12\r\n\x05state\x18\n \x01(\t\x12\x43\n\x08timeouts\x18\x0b \x01(\x0b\x32\x31.oak9.tython.gcp.kms.KmsKeyRingImportJobXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41ttestationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0ePublicKeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x1cKmsSecretCiphertextXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x81\x02\n\x13KmsSecretCiphertext\x12%\n\x1d\x61\x64\x64itional_authenticated_data\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\t\x12\x12\n\ncrypto_key\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x11\n\tplaintext\x18\x05 \x01(\t\x12\x43\n\x08timeouts\x18\x06 \x01(\x0b\x32\x31.oak9.tython.gcp.kms.KmsSecretCiphertextXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_kms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KMSCRYPTOKEY_LABELSENTRY._options = None
  _KMSCRYPTOKEY_LABELSENTRY._serialized_options = b'8\001'
  _KMSKEYRINGIMPORTJOB_ATTESTATIONENTRY._options = None
  _KMSKEYRINGIMPORTJOB_ATTESTATIONENTRY._serialized_options = b'8\001'
  _KMSKEYRINGIMPORTJOB_PUBLICKEYENTRY._options = None
  _KMSKEYRINGIMPORTJOB_PUBLICKEYENTRY._serialized_options = b'8\001'
  _KMSCRYPTOKEYXTIMEOUTS._serialized_start=63
  _KMSCRYPTOKEYXTIMEOUTS._serialized_end=134
  _KMSCRYPTOKEYXVERSIONTEMPLATE._serialized_start=136
  _KMSCRYPTOKEYXVERSIONTEMPLATE._serialized_end=211
  _KMSCRYPTOKEY._serialized_start=214
  _KMSCRYPTOKEY._serialized_end=716
  _KMSCRYPTOKEY_LABELSENTRY._serialized_start=671
  _KMSCRYPTOKEY_LABELSENTRY._serialized_end=716
  _KMSCRYPTOKEYIAMBINDINGXCONDITION._serialized_start=718
  _KMSCRYPTOKEYIAMBINDINGXCONDITION._serialized_end=808
  _KMSCRYPTOKEYIAMBINDING._serialized_start=811
  _KMSCRYPTOKEYIAMBINDING._serialized_end=1046
  _KMSCRYPTOKEYIAMMEMBERXCONDITION._serialized_start=1048
  _KMSCRYPTOKEYIAMMEMBERXCONDITION._serialized_end=1137
  _KMSCRYPTOKEYIAMMEMBER._serialized_start=1140
  _KMSCRYPTOKEYIAMMEMBER._serialized_end=1372
  _KMSCRYPTOKEYIAMPOLICY._serialized_start=1375
  _KMSCRYPTOKEYIAMPOLICY._serialized_end=1525
  _KMSKEYRINGXTIMEOUTS._serialized_start=1527
  _KMSKEYRINGXTIMEOUTS._serialized_end=1580
  _KMSKEYRING._serialized_start=1583
  _KMSKEYRING._serialized_end=1773
  _KMSKEYRINGIAMBINDINGXCONDITION._serialized_start=1775
  _KMSKEYRINGIAMBINDINGXCONDITION._serialized_end=1863
  _KMSKEYRINGIAMBINDING._serialized_start=1866
  _KMSKEYRINGIAMBINDING._serialized_end=2095
  _KMSKEYRINGIAMMEMBERXCONDITION._serialized_start=2097
  _KMSKEYRINGIAMMEMBERXCONDITION._serialized_end=2184
  _KMSKEYRINGIAMMEMBER._serialized_start=2187
  _KMSKEYRINGIAMMEMBER._serialized_end=2413
  _KMSKEYRINGIAMPOLICY._serialized_start=2416
  _KMSKEYRINGIAMPOLICY._serialized_end=2562
  _KMSKEYRINGIMPORTJOBXTIMEOUTS._serialized_start=2564
  _KMSKEYRINGIMPORTJOBXTIMEOUTS._serialized_end=2626
  _KMSKEYRINGIMPORTJOB._serialized_start=2629
  _KMSKEYRINGIMPORTJOB._serialized_end=3187
  _KMSKEYRINGIMPORTJOB_ATTESTATIONENTRY._serialized_start=3087
  _KMSKEYRINGIMPORTJOB_ATTESTATIONENTRY._serialized_end=3137
  _KMSKEYRINGIMPORTJOB_PUBLICKEYENTRY._serialized_start=3139
  _KMSKEYRINGIMPORTJOB_PUBLICKEYENTRY._serialized_end=3187
  _KMSSECRETCIPHERTEXTXTIMEOUTS._serialized_start=3189
  _KMSSECRETCIPHERTEXTXTIMEOUTS._serialized_end=3251
  _KMSSECRETCIPHERTEXT._serialized_start=3254
  _KMSSECRETCIPHERTEXT._serialized_end=3511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_firewall_policy_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_firewall_pb2 as gcp_dot_gcp__compute__firewall__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3gcp/gcp_google_compute_firewall_policy_bundle.proto\x12\x35oak9.tython.gcp.google_compute_firewall_policy_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_firewall.proto\"\xcb\x02\n\x1bGoogleComputeFirewallPolicy\x12X\n\x17\x63ompute_firewall_policy\x18\x01 \x01(\x0b\x32\x37.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicy\x12o\n#compute_firewall_policy_association\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyAssociation\x12\x61\n\x1c\x63ompute_firewall_policy_rule\x18\x03 \x03(\x0b\x32;.oak9.tython.gcp.compute_firewall.ComputeFirewallPolicyRuleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_firewall_policy_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTEFIREWALLPOLICY._serialized_start=164
  _GOOGLECOMPUTEFIREWALLPOLICY._serialized_end=495
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Device(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_id: builtins.str
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_id: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_id", b"device_id", "enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___Device = Device

@typing_extensions.final
class IoT1Click(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROJECT_DEVICE_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def device(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Device]: ...
    @property
    def placement(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Placement]: ...
    @property
    def project(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Project]: ...
    @property
    def project_device_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectDeviceTemplate]: ...
    def __init__(
        self,
        *,
        device: collections.abc.Iterable[global___Device] | None = ...,
        placement: collections.abc.Iterable[global___Placement] | None = ...,
        project: collections.abc.Iterable[global___Project] | None = ...,
        project_device_template: collections.abc.Iterable[global___ProjectDeviceTemplate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device", "placement", b"placement", "project", b"project", "project_device_template", b"project_device_template"]) -> None: ...

global___IoT1Click = IoT1Click

@typing_extensions.final
class Placement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AssociatedDevicesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PLACEMENT_NAME_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    ASSOCIATED_DEVICES_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    placement_name: builtins.str
    project_name: builtins.str
    @property
    def associated_devices(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        placement_name: builtins.str = ...,
        project_name: builtins.str = ...,
        associated_devices: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["associated_devices", b"associated_devices", "attributes", b"attributes", "placement_name", b"placement_name", "project_name", b"project_name", "resource_info", b"resource_info"]) -> None: ...

global___Placement = Placement

@typing_extensions.final
class ProjectPlacementTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DeviceTemplatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DefaultAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_TEMPLATES_FIELD_NUMBER: builtins.int
    DEFAULT_ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def device_templates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def default_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_templates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_attributes", b"default_attributes", "device_templates", b"device_templates", "resource_info", b"resource_info"]) -> None: ...

global___ProjectPlacementTemplate = ProjectPlacementTemplate

@typing_extensions.final
class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PLACEMENT_TEMPLATE_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def placement_template(self) -> global___ProjectPlacementTemplate: ...
    project_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        placement_template: global___ProjectPlacementTemplate | None = ...,
        project_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["placement_template", b"placement_template", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "placement_template", b"placement_template", "project_name", b"project_name", "resource_info", b"resource_info"]) -> None: ...

global___Project = Project

@typing_extensions.final
class ProjectDeviceTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CallbackOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    CALLBACK_OVERRIDES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_type: builtins.str
    @property
    def callback_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_type: builtins.str = ...,
        callback_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["callback_overrides", b"callback_overrides", "device_type", b"device_type", "resource_info", b"resource_info"]) -> None: ...

global___ProjectDeviceTemplate = ProjectDeviceTemplate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeRouteXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeRouteXTimeouts = ComputeRouteXTimeouts

@typing_extensions.final
class ComputeRoute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEST_RANGE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NEXT_HOP_GATEWAY_FIELD_NUMBER: builtins.int
    NEXT_HOP_ILB_FIELD_NUMBER: builtins.int
    NEXT_HOP_INSTANCE_FIELD_NUMBER: builtins.int
    NEXT_HOP_INSTANCE_ZONE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_FIELD_NUMBER: builtins.int
    NEXT_HOP_NETWORK_FIELD_NUMBER: builtins.int
    NEXT_HOP_VPN_TUNNEL_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    dest_range: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    next_hop_gateway: builtins.str
    next_hop_ilb: builtins.str
    next_hop_instance: builtins.str
    next_hop_instance_zone: builtins.str
    next_hop_ip: builtins.str
    next_hop_network: builtins.str
    next_hop_vpn_tunnel: builtins.str
    priority: builtins.float
    project: builtins.str
    self_link: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeouts(self) -> global___ComputeRouteXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        dest_range: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        next_hop_gateway: builtins.str = ...,
        next_hop_ilb: builtins.str = ...,
        next_hop_instance: builtins.str = ...,
        next_hop_instance_zone: builtins.str = ...,
        next_hop_ip: builtins.str = ...,
        next_hop_network: builtins.str = ...,
        next_hop_vpn_tunnel: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        timeouts: global___ComputeRouteXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "dest_range", b"dest_range", "id", b"id", "name", b"name", "network", b"network", "next_hop_gateway", b"next_hop_gateway", "next_hop_ilb", b"next_hop_ilb", "next_hop_instance", b"next_hop_instance", "next_hop_instance_zone", b"next_hop_instance_zone", "next_hop_ip", b"next_hop_ip", "next_hop_network", b"next_hop_network", "next_hop_vpn_tunnel", b"next_hop_vpn_tunnel", "priority", b"priority", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "tags", b"tags", "timeouts", b"timeouts"]) -> None: ...

global___ComputeRoute = ComputeRoute



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataflowJobXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_FIELD_NUMBER: builtins.int
    update: builtins.str
    def __init__(
        self,
        *,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["update", b"update"]) -> None: ...

global___DataflowJobXTimeouts = DataflowJobXTimeouts

@typing_extensions.final
class DataflowJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TransformNameMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_EXPERIMENTS_FIELD_NUMBER: builtins.int
    ENABLE_STREAMING_ENGINE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_CONFIGURATION_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MAX_WORKERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    ON_DELETE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    SKIP_WAIT_ON_JOB_TERMINATION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TEMP_GCS_LOCATION_FIELD_NUMBER: builtins.int
    TEMPLATE_GCS_PATH_FIELD_NUMBER: builtins.int
    TRANSFORM_NAME_MAPPING_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def additional_experiments(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_streaming_engine: builtins.bool
    id: builtins.str
    ip_configuration: builtins.str
    job_id: builtins.str
    kms_key_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    max_workers: builtins.float
    name: builtins.str
    network: builtins.str
    on_delete: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    project: builtins.str
    region: builtins.str
    service_account_email: builtins.str
    skip_wait_on_job_termination: builtins.bool
    state: builtins.str
    subnetwork: builtins.str
    temp_gcs_location: builtins.str
    template_gcs_path: builtins.str
    @property
    def transform_name_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    type: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___DataflowJobXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_experiments: collections.abc.Iterable[builtins.str] | None = ...,
        enable_streaming_engine: builtins.bool = ...,
        id: builtins.str = ...,
        ip_configuration: builtins.str = ...,
        job_id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        max_workers: builtins.float = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        on_delete: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        service_account_email: builtins.str = ...,
        skip_wait_on_job_termination: builtins.bool = ...,
        state: builtins.str = ...,
        subnetwork: builtins.str = ...,
        temp_gcs_location: builtins.str = ...,
        template_gcs_path: builtins.str = ...,
        transform_name_mapping: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___DataflowJobXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_experiments", b"additional_experiments", "enable_streaming_engine", b"enable_streaming_engine", "id", b"id", "ip_configuration", b"ip_configuration", "job_id", b"job_id", "kms_key_name", b"kms_key_name", "labels", b"labels", "machine_type", b"machine_type", "max_workers", b"max_workers", "name", b"name", "network", b"network", "on_delete", b"on_delete", "parameters", b"parameters", "project", b"project", "region", b"region", "resource_info", b"resource_info", "service_account_email", b"service_account_email", "skip_wait_on_job_termination", b"skip_wait_on_job_termination", "state", b"state", "subnetwork", b"subnetwork", "temp_gcs_location", b"temp_gcs_location", "template_gcs_path", b"template_gcs_path", "timeouts", b"timeouts", "transform_name_mapping", b"transform_name_mapping", "type", b"type", "zone", b"zone"]) -> None: ...

global___DataflowJob = DataflowJob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_firewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIREWALL_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def firewall_policies(self) -> global___FirewallPolicies: ...
    def __init__(
        self,
        *,
        firewall_policies: global___FirewallPolicies | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["firewall_policies", b"firewall_policies"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["firewall_policies", b"firewall_policies"]) -> None: ...

global___Microsoft_Network_firewallPolicies = Microsoft_Network_firewallPolicies

@typing_extensions.final
class FirewallPoliciesRuleCollectionGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_COLLECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    priority: builtins.int
    @property
    def rule_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirewallPolicyRuleCollection]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rule_collections: collections.abc.Iterable[global___FirewallPolicyRuleCollection] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "priority", b"priority", "resource_info", b"resource_info", "rule_collections", b"rule_collections"]) -> None: ...

global___FirewallPoliciesRuleCollectionGroups = FirewallPoliciesRuleCollectionGroups

@typing_extensions.final
class FirewallPolicyRuleCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_COLLECTION_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    priority: builtins.int
    rule_collection_type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rule_collection_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "priority", b"priority", "rule_collection_type", b"rule_collection_type"]) -> None: ...

global___FirewallPolicyRuleCollection = FirewallPolicyRuleCollection

@typing_extensions.final
class FirewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    BASE_POLICY_FIELD_NUMBER: builtins.int
    THREAT_INTEL_MODE_FIELD_NUMBER: builtins.int
    THREAT_INTEL_WHITELIST_FIELD_NUMBER: builtins.int
    DNS_SETTINGS_FIELD_NUMBER: builtins.int
    INTRUSION_DETECTION_FIELD_NUMBER: builtins.int
    TRANSPORT_SECURITY_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    FIREWALL_POLICIES_RULE_COLLECTION_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    base_policy: builtins.str
    threat_intel_mode: builtins.str
    @property
    def threat_intel_whitelist(self) -> global___FirewallPolicyThreatIntelWhitelist: ...
    @property
    def dns_settings(self) -> global___DnsSettings: ...
    @property
    def intrusion_detection(self) -> global___FirewallPolicyIntrusionDetection: ...
    @property
    def transport_security(self) -> global___FirewallPolicyTransportSecurity: ...
    @property
    def sku(self) -> global___FirewallPolicySku: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    @property
    def firewall_policies_rule_collection_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirewallPoliciesRuleCollectionGroups]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        base_policy: builtins.str = ...,
        threat_intel_mode: builtins.str = ...,
        threat_intel_whitelist: global___FirewallPolicyThreatIntelWhitelist | None = ...,
        dns_settings: global___DnsSettings | None = ...,
        intrusion_detection: global___FirewallPolicyIntrusionDetection | None = ...,
        transport_security: global___FirewallPolicyTransportSecurity | None = ...,
        sku: global___FirewallPolicySku | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        firewall_policies_rule_collection_groups: collections.abc.Iterable[global___FirewallPoliciesRuleCollectionGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_settings", b"dns_settings", "identity", b"identity", "intrusion_detection", b"intrusion_detection", "resource_info", b"resource_info", "sku", b"sku", "threat_intel_whitelist", b"threat_intel_whitelist", "transport_security", b"transport_security"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_policy", b"base_policy", "dns_settings", b"dns_settings", "firewall_policies_rule_collection_groups", b"firewall_policies_rule_collection_groups", "identity", b"identity", "intrusion_detection", b"intrusion_detection", "location", b"location", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "threat_intel_mode", b"threat_intel_mode", "threat_intel_whitelist", b"threat_intel_whitelist", "transport_security", b"transport_security"]) -> None: ...

global___FirewallPolicies = FirewallPolicies

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class FirewallPolicySku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIER_FIELD_NUMBER: builtins.int
    tier: builtins.str
    def __init__(
        self,
        *,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tier", b"tier"]) -> None: ...

global___FirewallPolicySku = FirewallPolicySku

@typing_extensions.final
class FirewallPolicyTransportSecurity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    @property
    def certificate_authority(self) -> global___FirewallPolicyCertificateAuthority: ...
    def __init__(
        self,
        *,
        certificate_authority: global___FirewallPolicyCertificateAuthority | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate_authority", b"certificate_authority"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority", b"certificate_authority"]) -> None: ...

global___FirewallPolicyTransportSecurity = FirewallPolicyTransportSecurity

@typing_extensions.final
class FirewallPolicyCertificateAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_SECRET_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    key_vault_secret_id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        key_vault_secret_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_secret_id", b"key_vault_secret_id", "name", b"name"]) -> None: ...

global___FirewallPolicyCertificateAuthority = FirewallPolicyCertificateAuthority

@typing_extensions.final
class FirewallPolicyIntrusionDetection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    mode: builtins.str
    @property
    def configuration(self) -> global___FirewallPolicyIntrusionDetectionConfiguration: ...
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
        configuration: global___FirewallPolicyIntrusionDetectionConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "mode", b"mode"]) -> None: ...

global___FirewallPolicyIntrusionDetection = FirewallPolicyIntrusionDetection

@typing_extensions.final
class FirewallPolicyIntrusionDetectionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_OVERRIDES_FIELD_NUMBER: builtins.int
    BYPASS_TRAFFIC_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def signature_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirewallPolicyIntrusionDetectionSignatureSpecification]: ...
    @property
    def bypass_traffic_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FirewallPolicyIntrusionDetectionBypassTrafficSpecifications]: ...
    def __init__(
        self,
        *,
        signature_overrides: collections.abc.Iterable[global___FirewallPolicyIntrusionDetectionSignatureSpecification] | None = ...,
        bypass_traffic_settings: collections.abc.Iterable[global___FirewallPolicyIntrusionDetectionBypassTrafficSpecifications] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_traffic_settings", b"bypass_traffic_settings", "signature_overrides", b"signature_overrides"]) -> None: ...

global___FirewallPolicyIntrusionDetectionConfiguration = FirewallPolicyIntrusionDetectionConfiguration

@typing_extensions.final
class FirewallPolicyIntrusionDetectionBypassTrafficSpecifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESSES_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESSES_FIELD_NUMBER: builtins.int
    DESTINATION_PORTS_FIELD_NUMBER: builtins.int
    SOURCE_IP_GROUPS_FIELD_NUMBER: builtins.int
    DESTINATION_IP_GROUPS_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    protocol: builtins.str
    @property
    def source_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_ip_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_ip_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        protocol: builtins.str = ...,
        source_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        destination_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        destination_ports: collections.abc.Iterable[builtins.str] | None = ...,
        source_ip_groups: collections.abc.Iterable[builtins.str] | None = ...,
        destination_ip_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "destination_addresses", b"destination_addresses", "destination_ip_groups", b"destination_ip_groups", "destination_ports", b"destination_ports", "name", b"name", "protocol", b"protocol", "source_addresses", b"source_addresses", "source_ip_groups", b"source_ip_groups"]) -> None: ...

global___FirewallPolicyIntrusionDetectionBypassTrafficSpecifications = FirewallPolicyIntrusionDetectionBypassTrafficSpecifications

@typing_extensions.final
class FirewallPolicyIntrusionDetectionSignatureSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    id: builtins.str
    mode: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "mode", b"mode"]) -> None: ...

global___FirewallPolicyIntrusionDetectionSignatureSpecification = FirewallPolicyIntrusionDetectionSignatureSpecification

@typing_extensions.final
class DnsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_FIELD_NUMBER: builtins.int
    ENABLE_PROXY_FIELD_NUMBER: builtins.int
    REQUIRE_PROXY_FOR_NETWORK_RULES_FIELD_NUMBER: builtins.int
    @property
    def servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_proxy: builtins.bool
    require_proxy_for_network_rules: builtins.bool
    def __init__(
        self,
        *,
        servers: collections.abc.Iterable[builtins.str] | None = ...,
        enable_proxy: builtins.bool = ...,
        require_proxy_for_network_rules: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_proxy", b"enable_proxy", "require_proxy_for_network_rules", b"require_proxy_for_network_rules", "servers", b"servers"]) -> None: ...

global___DnsSettings = DnsSettings

@typing_extensions.final
class FirewallPolicyThreatIntelWhitelist(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    FQDNS_FIELD_NUMBER: builtins.int
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        fqdns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdns", b"fqdns", "ip_addresses", b"ip_addresses"]) -> None: ...

global___FirewallPolicyThreatIntelWhitelist = FirewallPolicyThreatIntelWhitelist



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SlackChannelConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SLACK_WORKSPACE_ID_FIELD_NUMBER: builtins.int
    SLACK_CHANNEL_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_NAME_FIELD_NUMBER: builtins.int
    IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARNS_FIELD_NUMBER: builtins.int
    LOGGING_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    slack_workspace_id: builtins.str
    slack_channel_id: builtins.str
    configuration_name: builtins.str
    iam_role_arn: builtins.str
    @property
    def sns_topic_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    logging_level: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        slack_workspace_id: builtins.str = ...,
        slack_channel_id: builtins.str = ...,
        configuration_name: builtins.str = ...,
        iam_role_arn: builtins.str = ...,
        sns_topic_arns: collections.abc.Iterable[builtins.str] | None = ...,
        logging_level: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_name", b"configuration_name", "iam_role_arn", b"iam_role_arn", "logging_level", b"logging_level", "resource_info", b"resource_info", "slack_channel_id", b"slack_channel_id", "slack_workspace_id", b"slack_workspace_id", "sns_topic_arns", b"sns_topic_arns"]) -> None: ...

global___SlackChannelConfiguration = SlackChannelConfiguration

@typing_extensions.final
class Chatbot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_CHANNEL_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def slack_channel_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SlackChannelConfiguration]: ...
    def __init__(
        self,
        *,
        slack_channel_configuration: collections.abc.Iterable[global___SlackChannelConfiguration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["slack_channel_configuration", b"slack_channel_configuration"]) -> None: ...

global___Chatbot = Chatbot
